import 'package:dcoupon_sdk_flutter_package/src/core/error/failures.dart';
import 'package:dartz/dartz.dart';
import 'package:dcoupon_sdk_flutter_package/src/data/datasources/promotion_remote_data_source.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/repositories/promotion_repository.dart';

class PromotionRepositoryImpl implements PromotionRepository {
  final PromotionRemoteDataSource? remoteDataSource;

  PromotionRepositoryImpl({
    this.remoteDataSource,
  });

  @override
  Future<Either<Failure, dynamic>> getPromotionDetail({
    String? promotionToken,
    String? publisherId,
  }) async {
    return await remoteDataSource!.getPromotionDetail(
      promotionToken: promotionToken,
      publisherId: publisherId,
    );
  }

  @override
  Future<Either<Failure, dynamic>> getPromotions({
    int? start,
    int? limit,
    List<String>? categoryIds,
    List<String>? storeIds,
    List<String>? retailerTokens,
    List<String>? companyTokens,
    String? textSearch,
    String? zipcode,
    String? latitude,
    String? longitude,
    String? radius,
    String? orderBy,
    String? publisherId,
  }) async {
    return await remoteDataSource!.getPromotions(
      start: start,
      limit: limit,
      categoryIds: categoryIds,
      storeIds: storeIds,
      retailerTokens: retailerTokens,
      companyTokens: companyTokens,
      textSearch: textSearch,
      zipcode: zipcode,
      latitude: latitude,
      longitude: longitude,
      radius: radius,
      orderBy: orderBy,
      publisherId: publisherId,
    );
  }

  @override
  Future<Either<Failure, dynamic>> getCategories({
    String? publisherId,
  }) async {
    return await remoteDataSource!.getCategories(
      publisherId: publisherId,
    );
  }

  @override
  Future<Either<Failure, dynamic>> getCompanies({
    int? start,
    int? limit,
    String? publisherId,
  }) async {
    return await remoteDataSource!.getCompanies(
      start: start,
      limit: limit,
      publisherId: publisherId,
    );
  }

  @override
  Future<Either<Failure, dynamic>> getRetailers({
    int? start,
    int? limit,
    String? publisherId,
  }) async {
    return await remoteDataSource!.getRetailers(
      start: start,
      limit: limit,
      publisherId: publisherId,
    );
  }
}
